# Esbonio Demo

Welcome to the demo documentation site for the Esbonio language server!

This site is intended to complement the [Esbonio tutorial][tutorial] and serve as an overview of all of the features provided by the language server.
For the best experience it's recommended that you view the source for the demo from your editor of choice - with the Esbonio lanaguage server enabled of course!

## Updating dependencies

The dependencies pinned in `requirements.txt` are updated using `tox`

```
tox run -e update-dependencies
```

[tutorial]: https://docs.esbon.io/en/latest/lsp/getting-started.html
